@@ -17,10 +17,14 @@ def prepare_env(platform: str, config: json, select_config: str = None):
         print("{} = {}".format(var_name, value))
         os.environ[var_name] = value
         if platform == "gha":
-            subprocess.run(
-                'echo "{}={}" >> $GITHUB_ENV'.format(var_name, value),
-                shell=True
-            )
+            if compiler == "VISUAL":
+                os.system('echo {}={}>> {}'.format(var_name, value, os.getenv("GITHUB_ENV")))
+            else:
+                subprocess.run(
+                    'echo "{}={}" >> $GITHUB_ENV'.format(var_name, value),
+                    shell=True
+                )
+
         if platform == "azp":
             if compiler == "VISUAL":
                 subprocess.run(
@@ -77,15 +81,25 @@ def prepare_env(platform: str, config: json, select_config: str = None):
                 shell=True
             )
 
-    if platform == "azp" and compiler == "VISUAL":
-        with open(os.path.join(os.path.dirname(__file__), "prepare_env_azp_windows.ps1"), "r") as file:
-            content = file.read()
-            file.close()
+        if compiler == "VISUAL":
+            with open(os.path.join(os.path.dirname(__file__), "prepare_env_azp_windows.ps1"), "r") as file:
+                content = file.read()
+                file.close()
 
-        with open("execute.ps1", "w", encoding="utf-8") as file:
-            file.write(content)
-            file.close()
+            with open("execute.ps1", "w", encoding="utf-8") as file:
+                file.write(content)
+                file.close()
 
-        subprocess.run("powershell -file {}".format(os.path.join(os.getcwd(), "execute.ps1")), shell=True, check=True)
+            subprocess.run("pip install --upgrade cmake", shell=True, check=True)
+            subprocess.run("powershell -file {}".format(os.path.join(os.getcwd(), "execute.ps1")), shell=True, check=True)
+
+    if platform == "gha" and (compiler == "GCC" or compiler == "CLANG"):
+        subprocess.run('docker system prune --all --force --volumes', shell=True)
+        subprocess.run('sudo rm -rf "/usr/local/share/boost"', shell=True)
+        subprocess.run('sudo rm -rf "$AGENT_TOOLSDIRECTORY/CodeQL"', shell=True)
+        subprocess.run('sudo rm -rf "$AGENT_TOOLSDIRECTORY/Ruby"', shell=True)
+        subprocess.run('sudo rm -rf "$AGENT_TOOLSDIRECTORY/boost"', shell=True)
+        subprocess.run('sudo rm -rf "$AGENT_TOOLSDIRECTORY/go"', shell=True)
+        subprocess.run('sudo rm -rf "$AGENT_TOOLSDIRECTORY/node"', shell=True)
 
     subprocess.run("conan user", shell=True)
